import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { r as removeDisabledFalse, f as renderDynamicChildSlots, E as slotHasContent, z as IcInformationStatus, C as successIcon } from './helpers.js';

const icInputComponentContainerCss = "ic-input-component-container{display:flex;border:var(--ic-border-width) solid\n    var(--border-color, var(--ic-architectural-400));border-radius:var(--ic-border-radius);transition:var(--ic-easing-transition-slow);height:2.5rem;min-height:2.5rem;width:var(--input-width, 20rem);padding:var(--ic-space-1px);background-color:var(--input-bg-color, var(--ic-color-background-primary));box-sizing:border-box;fill:var(--ic-architectural-400);outline:none}ic-input-component-container.ic-input-component-container-full-width{width:100%}ic-input-component-container.ic-input-component-container-disabled,ic-input-component-container.ic-input-component-container-disabled:hover{border:var(--ic-border-width) dashed\n    var(--border-color-disabled, var(--ic-color-border-neutral-disabled))}ic-input-component-container.ic-input-component-container-readonly,ic-input-component-container.ic-input-component-container-small.ic-input-component-container-readonly,ic-input-component-container.ic-input-component-container-large.ic-input-component-container-readonly{height:auto;background:transparent}ic-input-component-container.ic-input-component-container-readonly,ic-input-component-container.ic-input-component-container-readonly:hover{border:none;padding:0}ic-input-component-container.ic-input-component-container-error{border:var(--ic-space-xxxs) solid\n    var(--border-color-error, var(--ic-color-border-error));padding:0}ic-input-component-container.ic-input-component-container-error:hover{border:var(--ic-space-xxxs) solid\n    var(--border-color-error-hover, var(--ic-color-border-error-hover))}ic-input-component-container.ic-input-component-container-error:focus-within{border:var(--ic-space-xxxs) solid\n    var(--border-color-error-pressed, var(--ic-color-border-error-pressed))}ic-input-component-container.ic-input-component-container-warning{border:var(--ic-space-xxxs) solid\n    var(--border-color-warning, var(--ic-color-border-warning));padding:0}ic-input-component-container.ic-input-component-container-warning:hover{border:var(--ic-space-xxxs) solid\n    var(--border-color-warning-hover, var(--ic-color-border-warning-hover))}ic-input-component-container.ic-input-component-container-warning:focus-within{border:var(--ic-space-xxxs) solid\n    var(--border-color-warning-pressed, var(--ic-color-border-warning-pressed))}ic-input-component-container.ic-input-component-container-success{border:var(--ic-space-xxxs) solid\n    var(--border-color-success, var(--ic-color-border-success));padding:0}ic-input-component-container.ic-input-component-container-success:hover{border:var(--ic-space-xxxs) solid\n    var(--border-color-success-hover, var(--ic-color-border-success-hover))}ic-input-component-container.ic-input-component-container-success:focus-within{border:var(--ic-space-xxxs) solid\n    var(--border-color-success-pressed, var(--ic-color-border-success-pressed))}ic-input-component-container.ic-input-component-container-small{height:var(--ic-space-xl);min-height:var(--ic-space-xl)}ic-input-component-container.ic-input-component-container-large{height:var(--ic-space-xxl);min-height:var(--ic-space-xxl)}ic-input-component-container.ic-input-component-container-multiline{height:auto}ic-input-component-container .icon-container{margin-top:var(--ic-space-xxs);margin-left:0.438rem;display:flex;align-items:center}ic-input-component-container.ic-input-component-container-multiline .icon-container,ic-input-component-container.ic-input-component-container-multiline.ic-input-component-container-small .icon-container{margin-top:0.375rem;display:block}ic-input-component-container.ic-input-component-container-readonly .icon-container{margin-left:-0.313rem}ic-input-component-container.ic-input-component-container-disabled ::-moz-placeholder{display:none}ic-input-component-container.ic-input-component-container-disabled ::placeholder{display:none}ic-input-component-container .inline-success{margin:var(--ic-space-xs) 0.375rem;display:flex;align-items:center}ic-input-component-container .inline-success>svg{fill:var(--ic-input-component-container-success-icon-inline-color);height:1.25rem;width:1.25rem}ic-input-component-container:hover{border:var(--ic-input-component-container-hover-border);border-color:var(--border-color-hover, var(--ic-color-border-neutral-hover));color:var(--ic-action-monochrome-hover-dark)}ic-input-component-container:focus{border:var(--ic-border-pressed);border-color:var(\n    --border-color-pressed,\n    var(--ic-color-border-neutral-pressed)\n  )}.focus-indicator{display:flex;width:100%;margin:-0.125rem;padding:0.125rem;border-radius:var(--ic-border-radius);transition:var(--ic-easing-transition-fast)}.focus-indicator:focus-within,.focus-indicator-enabled{box-shadow:var(--ic-border-focus)}.focus-indicator.ic-input-component-container-dark:focus-within{box-shadow:var(--ic-border-focus)}@media (forced-colors: active){ic-input-component-container,.focus-indicator{transition:none}ic-input-component-container:focus-within{border:var(--ic-border-width) solid Highlight;outline:0.125rem solid Highlight}ic-input-component-container.ic-input-component-container-disabled,ic-input-component-container.ic-input-component-container-disabled:hover{border:var(--ic-border-width) dashed GrayText}}";
const IcInputComponentContainerStyle0 = icInputComponentContainerCss;

const InputComponentContainer = /*@__PURE__*/ proxyCustomElement(class InputComponentContainer extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        /**
         *  If `true`, the disabled state will be set.
         */
        this.disabled = false;
        /**
         *  If `true`, the input component container will fill the width of the container it is in.
         */
        this.fullWidth = false;
        /**
         *  If `true`, the input component container will allow for multiple lines.
         */
        this.multiLine = false;
        /**
         *  If `true`, the readonly state will be set.
         */
        this.readonly = false;
        /**
         * The size of the input component container component.
         */
        this.size = "medium";
        /**
         *  If `true`, the validation will display inline.
         */
        this.validationInline = false;
        /**
         * The validation status of the input component container - e.g. 'error' | 'warning' | 'success'.
         */
        this.validationStatus = "";
    }
    watchDisabledHandler() {
        removeDisabledFalse(this.disabled, this.el);
    }
    componentWillLoad() {
        removeDisabledFalse(this.disabled, this.el);
    }
    componentDidLoad() {
        this.hostMutationObserver = new MutationObserver((mutationList) => renderDynamicChildSlots(mutationList, "left-icon", this));
        this.hostMutationObserver.observe(this.el, { childList: true });
    }
    render() {
        const { size, validationStatus, disabled, readonly, multiLine, fullWidth, validationInline, } = this;
        return (h(Host, { key: '86271007106caa930e823cd2a9b9242670a1d2c1', class: {
                [`ic-input-component-container-${size}`]: true,
                [`ic-input-component-container-${validationStatus}`]: validationStatus !== "" && !disabled && !readonly,
                "ic-input-component-container-disabled": !!disabled,
                "ic-input-component-container-readonly": !!readonly,
                "ic-input-component-container-multiline": !!multiLine,
                "ic-input-component-container-full-width": !!fullWidth,
            }, "aria-disabled": disabled ? "true" : null }, h("div", { key: '2b8e64e7cc2d78b34b816b080f7e5856b4aef254', class: "focus-indicator" }, slotHasContent(this.el, "left-icon") && (h("div", { key: '738e1d776664a7971bd97f36a68b8193849178ae', class: "icon-container" }, h("slot", { key: 'c6d5fa181367e1988b3e454b06c01345afa393ff', name: "left-icon" }))), h("slot", { key: '970ccdc08abd4dbf84248cc5708ab09ecbcbc0ae' }), validationInline &&
            validationStatus === IcInformationStatus.Success && (h("span", { key: '6c7cbd9c69c11a8688972039ba519829805d3ab7', class: "inline-success", innerHTML: successIcon })))));
    }
    get el() { return this; }
    static get watchers() { return {
        "disabled": ["watchDisabledHandler"]
    }; }
    static get style() { return IcInputComponentContainerStyle0; }
}, [4, "ic-input-component-container", {
        "disabled": [4],
        "fullWidth": [4, "full-width"],
        "multiLine": [4, "multi-line"],
        "readonly": [4],
        "size": [1],
        "validationInline": [4, "validation-inline"],
        "validationStatus": [1, "validation-status"]
    }, undefined, {
        "disabled": ["watchDisabledHandler"]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["ic-input-component-container"];
    components.forEach(tagName => { switch (tagName) {
        case "ic-input-component-container":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, InputComponentContainer);
            }
            break;
    } });
}

export { InputComponentContainer as I, defineCustomElement as d };

//# sourceMappingURL=ic-input-component-container2.js.map