import { EventEmitter } from "../../stencil-public-runtime";
import { IcStatusVariants, IcThemeMode, IcThemeSettings } from "../../utils/types";
/**
 * @slot message - Content is placed to the right of the title.
 * @slot action - Content is placed to the right of the message.
 * @slot neutral-icon - A custom neutral icon is placed to the left of the title. This will override the default icon if used.
 */
export declare class Alert {
    private hostMutationObserver;
    private systemThemeObserver;
    private darkMode;
    private messageEl?;
    private titleEl?;
    el: HTMLIcAlertElement;
    alertTitleWrap: boolean;
    visible: boolean;
    /**
     * If `true`, the alert will have the 'alert' ARIA role and will be announced to screen readers.
     */
    announced: boolean;
    /**
     * If `true`, the alert will have a close icon at the end to dismiss it.
     */
    dismissible: boolean;
    /**
     * The optional title to display at the start of the alert.
     */
    heading: string;
    /**
     * The main body message of the alert.
     */
    message?: string;
    /**
     * If `true`, the default icon for the neutral variant will appear on the left of the alert.
     */
    showDefaultIcon: boolean;
    /**
     * Sets the theme color to the dark or light theme color. "inherit" will set the color based on the system settings or ic-theme component.
     */
    theme: IcThemeMode;
    themeChangeHandler(): void;
    /**
     * If `true`, the title and message will appear above and below instead of inline.
     */
    titleAbove: boolean;
    /**
     * The variant of the alert which will be rendered.
     */
    variant: IcStatusVariants;
    /**
     * Is emitted when the user dismisses the alert.
     */
    icDismiss: EventEmitter<void>;
    disconnectedCallback(): void;
    componentWillLoad(): void;
    componentDidLoad(): void;
    componentDidUpdate(): void;
    handleClick(): void;
    darkModeChangeHandler(ev: CustomEvent<IcThemeSettings> | MediaQueryListEvent): void;
    private dismissAction;
    private calculateMinHeight;
    render(): any;
}
