import { EventEmitter } from "../../stencil-public-runtime";
import { IcSizes, IcThemeMode, IcIconPlacementOptions, IcButtonTooltipPlacement } from "../../utils/types";
/**
 * @slot icon - Content will be displayed alongside the toggle button label.
 * @slot badge - Badge component overlaying the top right of the toggle button.
 */
export declare class ToggleButton {
    el: HTMLIcToggleButtonElement;
    /**
     * The accessible label that will be applied to the toggle button. This is required for the icon variant of toggle buttons.
     */
    accessibleLabel?: string;
    /**
     * If `true`, the toggle button will be in a checked state.
     */
    checked?: boolean;
    /**
     * If `true`, the toggle button will be in disabled state.
     */
    disabled?: boolean;
    watchDisabledHandler(): void;
    /**
     * If `true`, the toggle button will fill the width of the container.
     */
    fullWidth?: boolean;
    /**
     * The placement of the icon in relation to the toggle button label.
     */
    iconPlacement?: IcIconPlacementOptions;
    /**
     * The label to display in the toggle button. This is required for the default variant of toggle buttons.
     */
    label?: string;
    /**
     * If `true`, the toggle button will be in loading state.
     */
    loading?: boolean;
    /**
     * If `true`, the toggle button will display as black in the light theme, and white in dark theme.
     */
    monochrome?: boolean;
    /**
     * The size of the toggle button to be displayed.
     */
    size?: IcSizes;
    /**
     * Sets the theme color to the dark or light theme color. "inherit" will set the color based on the system settings or ic-theme component.
     */
    theme?: IcThemeMode;
    /**
     * The position of the tooltip in relation to the toggle button.
     */
    tooltipPlacement?: IcButtonTooltipPlacement;
    /**
     * The variant of the toggle button.
     */
    variant?: "default" | "icon";
    /**
     * Emitted when the user clicks a toggle button.
     */
    icToggleChecked: EventEmitter<{
        checked: boolean;
    }>;
    componentWillLoad(): void;
    componentDidLoad(): void;
    handleHostClick(e: Event): void;
    private loopAttributes;
    private handleFocus;
    private handleClick;
    render(): any;
}
